"""
Django settings for uhepp_org project.

Generated by 'django-admin startproject' using Django 3.0.4.

For more information on this file, see
https://docs.djangoproject.com/en/3.0/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/3.0/ref/settings/
"""

import os

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/3.0/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!

SECURE_PROXY_SSL_HEADER = ('HTTP_X_FORWARDED_PROTO', 'https')
STATIC_ROOT = os.path.join(BASE_DIR, 'static')
STATIC_URL = '/static/'
ALLOWED_HOSTS = ['*']

if os.environ.get("PRODUCTION", False):
    SECRET_KEY = os.environ["SECRET_KEY"]
    DATABASES = {
        'default': {
            'ENGINE': 'django.db.backends.postgresql_psycopg2',
            'NAME': os.environ["POSTGRES_DB"],
            'USER': os.environ["POSTGRES_USER"],
            'PASSWORD': os.environ["POSTGRES_PASSWORD"],
            'HOST': os.environ["POSTGRES_HOST"],
            'PORT': '5432',
        }
    }

    OIDC_APP_NAME = os.environ["OIDC_APP_NAME"]
    OIDC_RP_CLIENT_ID = os.environ["OIDC_RP_CLIENT_ID"]
    LOGIN_REDIRECT_URL = os.environ["LOGIN_REDIRECT_URL"]
    LOGOUT_REDIRECT_URL = os.environ["LOGOUT_REDIRECT_URL"]

    REDIS_PREVIEW_PASSWORD = os.environ["REDIS_PASSWORD"]
    REDIS_PREVIEW_HOST = os.environ["REDIS_HOST"]
else:
    DEBUG = True
    SECRET_KEY = 'o-08ul47ou_j61zd)14(mjw&f&&ow95boa9nky=jn^%tv(+hqk'

    # Database
    # https://docs.djangoproject.com/en/3.0/ref/settings/#databases
    
    DATABASES = {
        'default': {
            'ENGINE': 'django.db.backends.sqlite3',
            'NAME': os.path.join(BASE_DIR, 'db.sqlite3'),
        }
    }
    STATIC_URL = '/static/'
    OIDC_APP_NAME = "uhepp-dev"
    OIDC_RP_CLIENT_ID = 'uhepp-dev'
    LOGIN_REDIRECT_URL = "http://dev.uhepp.org:8000/account/"
    LOGOUT_REDIRECT_URL = "http://dev.uhepp.org:8000/"

    REDIS_PREVIEW_PASSWORD = "not-so-secret"

    REDIS_PREVIEW_HOST = "localhost"

REDIS_PREVIEW_USERNAME = "web"
REDIS_PREVIEW_QUEUE = "preview_job_queue"

# Application definition
if 'OIDC_RP_CLIENT_SECRET' not in os.environ:
    print("Setting 'OIDC_RP_CLIENT_SECRET' to an empty string.")
    print("SSO will not work!")
OIDC_RP_CLIENT_SECRET = os.environ.get('OIDC_RP_CLIENT_SECRET', "")

OIDC_RP_SIGN_ALGO = "RS256"
OIDC_OP_JWKS_ENDPOINT = "https://auth.cern.ch/auth/realms/cern/protocol/openid-connect/certs"

OIDC_OP_AUTHORIZATION_ENDPOINT = "https://auth.cern.ch/auth/realms/cern/protocol/openid-connect/auth"
OIDC_OP_TOKEN_ENDPOINT = "https://auth.cern.ch/auth/realms/cern/protocol/openid-connect/token"
OIDC_OP_USER_ENDPOINT = "https://auth.cern.ch/auth/realms/cern/protocol/openid-connect/userinfo"


OIDC_RP_SCOPES = 'openid'

LOGIN_URL = "/login"

INSTALLED_APPS = [
    'uhepp_vault',
    'uhepp_api',
    'django.contrib.admin',
    'django.contrib.auth',
    'mozilla_django_oidc',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'rest_framework',
    'rest_framework.authtoken',
    'pygmentify',
    'svg',
    'crispy_forms',
    'django.contrib.humanize',
    'crispy_bootstrap4',
]

CRISPY_TEMPLATE_PACK = 'bootstrap4'

PYGMENTIFY = {
  'style': 'default',
  'cssclass': 'highlight border rounded bg-light px-2 m-2'
}

AUTHENTICATION_BACKENDS = [
    'uhepp_vault.auth.UHeppOIDCAB',
	'django.contrib.auth.backends.ModelBackend',
]

REST_FRAMEWORK = {
    'DEFAULT_AUTHENTICATION_CLASSES': [
        'uhepp_api.auth.ApiTokenAuthentication',
        'rest_framework.authentication.BasicAuthentication',
        'rest_framework.authentication.SessionAuthentication',
    ]
}

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

ROOT_URLCONF = 'uhepp_org.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'uhepp_org.wsgi.application'

# Password validation
# https://docs.djangoproject.com/en/3.0/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]


# Internationalization
# https://docs.djangoproject.com/en/3.0/topics/i18n/

LANGUAGE_CODE = 'en-us'

TIME_ZONE = 'UTC'

USE_I18N = True

USE_L10N = True

USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/3.0/howto/static-files/

STATIC_URL = '/static/'

DATETIME_INPUT_FORMATS = '%Y-%m-%d %H:%M'

SCHEMA_URL_1 = "https://gitlab.sauerburger.com/cern/fsauerbu/uhepp/-/raw/0.1.6/uhepp.schema.json"
SCHEMA_URL_2 = "https://gitlab.sauerburger.com/cern/fsauerbu/uhepp/-/raw/v0.2.0/uhepp.schema.json"
SCHEMA_URL_3 = "https://gitlab.sauerburger.com/cern/fsauerbu/uhepp/-/raw/0cff18263ff936853e65a120cf9da02cb0deee93/uhepp.schema.json"
SCHEMA_URL_4 = "https://gitlab.sauerburger.com/cern/fsauerbu/uhepp/-/raw/9dcfc67de4acb7cf9a56ebf28573e23541845af5/uhepp.schema.json"
