import logging
import os
from django import template
from django.conf import settings
from django.contrib.staticfiles import finders
from django.core.exceptions import ImproperlyConfigured
from django.utils.http import urlencode
from urllib.parse import quote

logger = logging.getLogger(__name__)
register = template.Library()

@register.simple_tag
def inline_svg(filename):
    SVG_DIRS = getattr(settings, 'SVG_DIRS', [])

    if type(SVG_DIRS) != list:
        raise ImproperlyConfigured('SVG_DIRS setting must be a list')

    path = None

    if SVG_DIRS:
        for directory in SVG_DIRS:
            svg_path = os.path.join(directory, '{filename}.svg'.format(
                filename=filename))

            if os.path.isfile(svg_path):
                path = svg_path
    else:
        path = finders.find(os.path.join('svg', '{filename}.svg'.format(
            filename=filename)), all=True)

    if not path:
        message = "SVG '{filename}.svg' not found".format(filename=filename)

        # Raise exception if DEBUG is True, else just log a warning.
        if settings.DEBUG:
            raise ValueError(message)
        else:
            logger.warning(message)
            return ''

    # Sometimes path can be a list/tuple if there's more than one file found
    if isinstance(path, (list, tuple)):
        path = path[0]

    with open(path) as svg_file:
        return "data:image/svg+xml," + quote(svg_file.read())
